==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d4/de2/airport_8h.js <==
var airport_8h =
[
    [ "AirportMovingData", "d6/d03/structAirportMovingData.html", "d6/d03/structAirportMovingData" ],
    [ "AirportFTAClass", "dd/de3/structAirportFTAClass.html", "dd/de3/structAirportFTAClass" ],
    [ "AirportFTA", "d6/dad/structAirportFTA.html", "d6/dad/structAirportFTA" ],
    [ "AirportMovementStates", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeb", [
      [ "TO_ALL", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebac23dce3979f99e8f384666811c7e98ee", null ],
      [ "HANGAR", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba9d7dab2fc6d0f745574b56106244f205", null ],
      [ "TERM1", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebae9449a5187aa293c672ab407ed808092", null ],
      [ "TERM2", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba7fe615394c24c5a54a03abd3ad023c72", null ],
      [ "TERM3", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba50c29070c32dd88a0f009fa97e900c1d", null ],
      [ "TERM4", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba11c5994187ff6376f443ed4d37d0a9e6", null ],
      [ "TERM5", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba3eb4ba8fefca4a0fef6e9a38be88cee2", null ],
      [ "TERM6", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba412a6b4a2f12b1fa5f57023a5d5c7cfc", null ],
      [ "HELIPAD1", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba79e125c08ba796bec7a73019019c5af8", null ],
      [ "HELIPAD2", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba227c4a8f3f46240bb7c655b1b9958bf8", null ],
      [ "TAKEOFF", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebab364c113ba85b72aa67856dceb444ef9", null ],
      [ "STARTTAKEOFF", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba2207b621f8c35775b208d71c5692401d", null ],
      [ "ENDTAKEOFF", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba2bd5a9afc697fbb53ea8bb97ba6cab46", null ],
      [ "HELITAKEOFF", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba0e2fc880229d8a44bc4170c86f927e0c", null ],
      [ "FLYING", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba9f6b27964ad25a0ed9cea7abb2f158c1", null ],
      [ "LANDING", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebaed02a50bc7e61636eb8ab00f1d31b9c4", null ],
      [ "ENDLANDING", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebac3d9f6e8827269d52c31fab9637c627a", null ],
      [ "HELILANDING", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebabcb80ecf133d54fad3cc945668926f85", null ],
      [ "HELIENDLANDING", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebae23315dd7947241a177e696f305809b1", null ],
      [ "TERM7", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebaeed5658077fd6eb8839b9a79b4513478", null ],
      [ "TERM8", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba5cfa902a7c6ed395e30f3c54b2a10bb7", null ],
      [ "HELIPAD3", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba7171897645ae5cf603b375f6fbd7bc22", null ],
      [ "MAX_HEADINGS", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebae54a76fcdc90a7015f141d1ce1e5bb71", null ]
    ] ],
    [ "AirportMovingDataFlags", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88b", [
      [ "AMED_NOSPDCLAMP", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88bab34c4f2c0c78501667dc814c8f472daa", null ],
      [ "AMED_TAKEOFF", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88babdb1ce1f72f0f1d906c57634f7e907ff", null ],
      [ "AMED_SLOWTURN", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88ba5598d3402bb25d143ddf8168dbf7187a", null ],
      [ "AMED_LAND", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88baa8c1814ecfae909252a0c374e0289c32", null ],
      [ "AMED_EXACTPOS", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88bac82aab628b41606db708981680ffed9e", null ],
      [ "AMED_BRAKE", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88ba02c20bcdc1197bf8503606fc9cb33fa5", null ],
      [ "AMED_HELI_RAISE", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88bae22400ba389a26200e0270f1c76491dc", null ],
      [ "AMED_HELI_LOWER", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88ba647431c6680d02ed254e009f97a6ccd6", null ],
      [ "AMED_HOLD", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88ba1a9484db342081eaab4428a398d5fcce", null ]
    ] ],
    [ "AirportTypes", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaff", [
      [ "AT_SMALL", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa00276c8b395f7ea83f3b860b9f82e814", null ],
      [ "AT_LARGE", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa505c0537ce2d1cc662b1b665399f8040", null ],
      [ "AT_HELIPORT", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffaa2c0dde559c713e9d84f0cfc5e25bc7f", null ],
      [ "AT_METROPOLITAN", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa200e2bb63543531d4f51d87e29f54d1c", null ],
      [ "AT_INTERNATIONAL", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffab62b61fa01b81c8aed5118c2ecd73dc5", null ],
      [ "AT_COMMUTER", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffacfd8906bd58b10d5b6f6a3be4aacacac", null ],
      [ "AT_HELIDEPOT", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa08ba07c747c85d600d80defaf5e069c8", null ],
      [ "AT_INTERCON", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffaa5c7973c93bd7ad59a3e73a82884205f", null ],
      [ "AT_HELISTATION", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa5a4e2d98fdcd75fc25c5acdf2491cba0", null ],
      [ "AT_OILRIG", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffad1a72b47da8aa48822dbf777c4dd30e6", null ],
      [ "NEW_AIRPORT_OFFSET", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffaa58532ff95248801f10f2af25806a40f", null ],
      [ "NUM_AIRPORTS_PER_GRF", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffaa593e32bbfd9f55e4ebf3f75b1c02784", null ],
      [ "NUM_AIRPORTS", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa2b72bfe9daab41e610beb7553007b5ee", null ],
      [ "AT_INVALID", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa0e75ba65fb6c82e5d993a8ba722376d5", null ],
      [ "AT_DUMMY", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa6dc06eaa9b78cd1e5908f43e46c00369", null ]
    ] ],
    [ "GetAirport", "d4/de2/airport_8h.html#a82ef6291ab3ffb03ae9c95cd6246d0b0", null ],
    [ "GetVehiclePosOnBuild", "d4/de2/airport_8h.html#a7a837fafa905dcd350819b1677b79c2d", null ],
    [ "RotateAirportMovingData", "d4/de2/airport_8h.html#a9c3f582273bb8eab3a46561c95dad0ef", null ],
    [ "AIRPORT_BUSY_block", "d4/de2/airport_8h.html#a5e844892876a29473a642164b6f2ecdc", null ],
    [ "AIRPORT_CLOSED_block", "d4/de2/airport_8h.html#a312b492ada26eb0d4f33336cb0fecd89", null ],
    [ "AIRPORT_ENTRANCE_block", "d4/de2/airport_8h.html#a500b0d50c1fb9f48bbf0798c8c66f6c9", null ],
    [ "HANGAR1_AREA_block", "d4/de2/airport_8h.html#a1c89d24a936307525d5856801f05c968", null ],
    [ "HANGAR2_AREA_block", "d4/de2/airport_8h.html#a9c5f887159525314ad08e6a4f992ba62", null ],
    [ "HELIPAD1_block", "d4/de2/airport_8h.html#a34ef67ed81c7b18d9c7a5fe3b9db19e3", null ],
    [ "HELIPAD2_block", "d4/de2/airport_8h.html#a85f11b9c7beb6f833d2d40e87a6259e6", null ],
    [ "HELIPAD3_block", "d4/de2/airport_8h.html#ae4c032e0698e3bcda01f4ca8e218fd88", null ],
    [ "HELIPAD_GROUP_block", "d4/de2/airport_8h.html#a8a26e34534865053b6c156768011944d", null ],
    [ "IN_WAY2_block", "d4/de2/airport_8h.html#a25bed87982f80f2744cd7a60f9d664d4", null ],
    [ "IN_WAY_block", "d4/de2/airport_8h.html#a37e9d173adb5f8f59d11947be41b03c1", null ],
    [ "INVALID_AIRPORTTILE", "d4/de2/airport_8h.html#a2ffe378e6877e984385e0da49bd3bde5", null ],
    [ "MAX_ELEMENTS", "d4/de2/airport_8h.html#a22c8d26f78739367e21b5f5c41aeb5af", null ],
    [ "MAX_HELIPADS", "d4/de2/airport_8h.html#a1bd4f9b4c0a86f860fa43a29b55ebcde", null ],
    [ "MAX_TERMINALS", "d4/de2/airport_8h.html#a541ee33c36ab7a5eba76fc96de75168b", null ],
    [ "NEW_AIRPORTTILE_OFFSET", "d4/de2/airport_8h.html#a6d13f3eaf87fc1e73456228cc304767c", null ],
    [ "NOTHING_block", "d4/de2/airport_8h.html#ab9b4f8e180dea6570902d8ae4d4d3070", null ],
    [ "NUM_AIRPORTTILES", "d4/de2/airport_8h.html#add0d86b6a46cf6278dae199740f4c124", null ],
    [ "NUM_AIRPORTTILES_PER_GRF", "d4/de2/airport_8h.html#a8d27f16fe10a1a90d40a8a0b5ad0e090", null ],
    [ "OUT_WAY2_block", "d4/de2/airport_8h.html#a36bf799ae037be66e8c9effc694aa03b", null ],
    [ "OUT_WAY_block", "d4/de2/airport_8h.html#ab3f52566f8f1b6b5f6b16982f81d11da", null ],
    [ "OUT_WAY_block2", "d4/de2/airport_8h.html#a8188ae2a2f4dc6c70a2aea8a56eb169a", null ],
    [ "PRE_HELIPAD_block", "d4/de2/airport_8h.html#a25a53a3e7ae80cbcc6e2b90ae22886e6", null ],
    [ "RUNWAY_IN2_block", "d4/de2/airport_8h.html#ac8a782e9d1f643f0f0c54a99dbf00987", null ],
    [ "RUNWAY_IN_block", "d4/de2/airport_8h.html#ab00a6df450cf7e7ec21e9aa128e6072f", null ],
    [ "RUNWAY_IN_OUT_block", "d4/de2/airport_8h.html#a2a166c136ebbbf56fe36cf767fbc5d68", null ],
    [ "RUNWAY_OUT2_block", "d4/de2/airport_8h.html#a91a30442650b08e2cb572029f39c73d2", null ],
    [ "RUNWAY_OUT_block", "d4/de2/airport_8h.html#a3b8c195c6cc658b31793087b2d58a50d", null ],
    [ "TAXIWAY_BUSY_block", "d4/de2/airport_8h.html#a675113d5d1ad95bb4b330597ed81d6f1", null ],
    [ "TERM1_block", "d4/de2/airport_8h.html#a8240fde23866ceebcd402110c59f11bc", null ],
    [ "TERM2_block", "d4/de2/airport_8h.html#ad4cca5b95d5ba0720ef6139c214a3ca7", null ],
    [ "TERM3_block", "d4/de2/airport_8h.html#a60b65d1f724f401cf5ee1c4f222012f6", null ],
    [ "TERM4_block", "d4/de2/airport_8h.html#a04d208abaa7b7e3ffb914311f361bb69", null ],
    [ "TERM5_block", "d4/de2/airport_8h.html#adb03bf948b385c3ffa442d3671e78de9", null ],
    [ "TERM6_block", "d4/de2/airport_8h.html#a9d1b4493066c7c335311626060fb9123", null ],
    [ "TERM7_block", "d4/de2/airport_8h.html#a134515ef1f4c05464172f4728eee1102", null ],
    [ "TERM8_block", "d4/de2/airport_8h.html#ae92a2ee696df7c115d1c2de281b4bc3e", null ],
    [ "TERM_GROUP1_block", "d4/de2/airport_8h.html#a58bda7988ccb93de888672e63e08e14b", null ],
    [ "TERM_GROUP2_block", "d4/de2/airport_8h.html#a2fbe99aab32a30788588fb1d8deb2205", null ],
    [ "TERM_GROUP2_ENTER1_block", "d4/de2/airport_8h.html#a31a846c1f8189f975d72b2f6db8fa1f0", null ],
    [ "TERM_GROUP2_ENTER2_block", "d4/de2/airport_8h.html#ad8bb747d653645960b82ca9b3fd39b8f", null ],
    [ "TERM_GROUP2_EXIT1_block", "d4/de2/airport_8h.html#a6798585ae39a010d8cd0ea70e1ad80d2", null ],
    [ "TERM_GROUP2_EXIT2_block", "d4/de2/airport_8h.html#a9a0c599cf909d0b138e72f81d4696e28", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d4/de2/airport_8h.js <==
var airport_8h =
[
    [ "AirportMovingData", "d6/d03/structAirportMovingData.html", "d6/d03/structAirportMovingData" ],
    [ "AirportFTAClass", "dd/de3/structAirportFTAClass.html", "dd/de3/structAirportFTAClass" ],
    [ "AirportFTA", "d6/dad/structAirportFTA.html", "d6/dad/structAirportFTA" ],
    [ "AirportMovementStates", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeb", [
      [ "TO_ALL", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebac23dce3979f99e8f384666811c7e98ee", null ],
      [ "HANGAR", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba9d7dab2fc6d0f745574b56106244f205", null ],
      [ "TERM1", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebae9449a5187aa293c672ab407ed808092", null ],
      [ "TERM2", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba7fe615394c24c5a54a03abd3ad023c72", null ],
      [ "TERM3", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba50c29070c32dd88a0f009fa97e900c1d", null ],
      [ "TERM4", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba11c5994187ff6376f443ed4d37d0a9e6", null ],
      [ "TERM5", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba3eb4ba8fefca4a0fef6e9a38be88cee2", null ],
      [ "TERM6", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba412a6b4a2f12b1fa5f57023a5d5c7cfc", null ],
      [ "HELIPAD1", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba79e125c08ba796bec7a73019019c5af8", null ],
      [ "HELIPAD2", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba227c4a8f3f46240bb7c655b1b9958bf8", null ],
      [ "TAKEOFF", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebab364c113ba85b72aa67856dceb444ef9", null ],
      [ "STARTTAKEOFF", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba2207b621f8c35775b208d71c5692401d", null ],
      [ "ENDTAKEOFF", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba2bd5a9afc697fbb53ea8bb97ba6cab46", null ],
      [ "HELITAKEOFF", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba0e2fc880229d8a44bc4170c86f927e0c", null ],
      [ "FLYING", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba9f6b27964ad25a0ed9cea7abb2f158c1", null ],
      [ "LANDING", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebaed02a50bc7e61636eb8ab00f1d31b9c4", null ],
      [ "ENDLANDING", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebac3d9f6e8827269d52c31fab9637c627a", null ],
      [ "HELILANDING", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebabcb80ecf133d54fad3cc945668926f85", null ],
      [ "HELIENDLANDING", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebae23315dd7947241a177e696f305809b1", null ],
      [ "TERM7", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebaeed5658077fd6eb8839b9a79b4513478", null ],
      [ "TERM8", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba5cfa902a7c6ed395e30f3c54b2a10bb7", null ],
      [ "HELIPAD3", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eeba7171897645ae5cf603b375f6fbd7bc22", null ],
      [ "MAX_HEADINGS", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebae54a76fcdc90a7015f141d1ce1e5bb71", null ],
      [ "TERMGROUP", "d4/de2/airport_8h.html#af7c9f9e514c5c9208331bf44418d1eebaf69e621cef1c71aeb7230c9edb352b72", null ]
    ] ],
    [ "AirportMovingDataFlags", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88b", [
      [ "AMED_NOSPDCLAMP", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88bab34c4f2c0c78501667dc814c8f472daa", null ],
      [ "AMED_TAKEOFF", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88babdb1ce1f72f0f1d906c57634f7e907ff", null ],
      [ "AMED_SLOWTURN", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88ba5598d3402bb25d143ddf8168dbf7187a", null ],
      [ "AMED_LAND", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88baa8c1814ecfae909252a0c374e0289c32", null ],
      [ "AMED_EXACTPOS", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88bac82aab628b41606db708981680ffed9e", null ],
      [ "AMED_BRAKE", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88ba02c20bcdc1197bf8503606fc9cb33fa5", null ],
      [ "AMED_HELI_RAISE", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88bae22400ba389a26200e0270f1c76491dc", null ],
      [ "AMED_HELI_LOWER", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88ba647431c6680d02ed254e009f97a6ccd6", null ],
      [ "AMED_HOLD", "d4/de2/airport_8h.html#a739a6723e290c2dc1d6f7340b6daf88ba1a9484db342081eaab4428a398d5fcce", null ]
    ] ],
    [ "AirportTypes", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaff", [
      [ "AT_SMALL", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa00276c8b395f7ea83f3b860b9f82e814", null ],
      [ "AT_LARGE", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa505c0537ce2d1cc662b1b665399f8040", null ],
      [ "AT_HELIPORT", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffaa2c0dde559c713e9d84f0cfc5e25bc7f", null ],
      [ "AT_METROPOLITAN", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa200e2bb63543531d4f51d87e29f54d1c", null ],
      [ "AT_INTERNATIONAL", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffab62b61fa01b81c8aed5118c2ecd73dc5", null ],
      [ "AT_COMMUTER", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffacfd8906bd58b10d5b6f6a3be4aacacac", null ],
      [ "AT_HELIDEPOT", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa08ba07c747c85d600d80defaf5e069c8", null ],
      [ "AT_INTERCON", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffaa5c7973c93bd7ad59a3e73a82884205f", null ],
      [ "AT_HELISTATION", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa5a4e2d98fdcd75fc25c5acdf2491cba0", null ],
      [ "AT_OILRIG", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffad1a72b47da8aa48822dbf777c4dd30e6", null ],
      [ "NEW_AIRPORT_OFFSET", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffaa58532ff95248801f10f2af25806a40f", null ],
      [ "NUM_AIRPORTS_PER_GRF", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffaa593e32bbfd9f55e4ebf3f75b1c02784", null ],
      [ "NUM_AIRPORTS", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa2b72bfe9daab41e610beb7553007b5ee", null ],
      [ "AT_INVALID", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa0e75ba65fb6c82e5d993a8ba722376d5", null ],
      [ "AT_DUMMY", "d4/de2/airport_8h.html#a70e25d7c11867a3d895312ea189bfaffa6dc06eaa9b78cd1e5908f43e46c00369", null ]
    ] ],
    [ "GetAirport", "d4/de2/airport_8h.html#a82ef6291ab3ffb03ae9c95cd6246d0b0", null ],
    [ "GetVehiclePosOnBuild", "d4/de2/airport_8h.html#a7a837fafa905dcd350819b1677b79c2d", null ],
    [ "RotateAirportMovingData", "d4/de2/airport_8h.html#a9c3f582273bb8eab3a46561c95dad0ef", null ],
    [ "AIRPORT_BUSY_block", "d4/de2/airport_8h.html#a5e844892876a29473a642164b6f2ecdc", null ],
    [ "AIRPORT_CLOSED_block", "d4/de2/airport_8h.html#a312b492ada26eb0d4f33336cb0fecd89", null ],
    [ "AIRPORT_ENTRANCE_block", "d4/de2/airport_8h.html#a500b0d50c1fb9f48bbf0798c8c66f6c9", null ],
    [ "HANGAR1_AREA_block", "d4/de2/airport_8h.html#a1c89d24a936307525d5856801f05c968", null ],
    [ "HANGAR2_AREA_block", "d4/de2/airport_8h.html#a9c5f887159525314ad08e6a4f992ba62", null ],
    [ "HELIPAD1_block", "d4/de2/airport_8h.html#a34ef67ed81c7b18d9c7a5fe3b9db19e3", null ],
    [ "HELIPAD2_block", "d4/de2/airport_8h.html#a85f11b9c7beb6f833d2d40e87a6259e6", null ],
    [ "HELIPAD3_block", "d4/de2/airport_8h.html#ae4c032e0698e3bcda01f4ca8e218fd88", null ],
    [ "HELIPAD_GROUP_block", "d4/de2/airport_8h.html#a8a26e34534865053b6c156768011944d", null ],
    [ "IN_WAY2_block", "d4/de2/airport_8h.html#a25bed87982f80f2744cd7a60f9d664d4", null ],
    [ "IN_WAY_block", "d4/de2/airport_8h.html#a37e9d173adb5f8f59d11947be41b03c1", null ],
    [ "INVALID_AIRPORTTILE", "d4/de2/airport_8h.html#a2ffe378e6877e984385e0da49bd3bde5", null ],
    [ "MAX_ELEMENTS", "d4/de2/airport_8h.html#a22c8d26f78739367e21b5f5c41aeb5af", null ],
    [ "MAX_HELIPADS", "d4/de2/airport_8h.html#a1bd4f9b4c0a86f860fa43a29b55ebcde", null ],
    [ "MAX_TERMINALS", "d4/de2/airport_8h.html#a541ee33c36ab7a5eba76fc96de75168b", null ],
    [ "NEW_AIRPORTTILE_OFFSET", "d4/de2/airport_8h.html#a6d13f3eaf87fc1e73456228cc304767c", null ],
    [ "NOTHING_block", "d4/de2/airport_8h.html#ab9b4f8e180dea6570902d8ae4d4d3070", null ],
    [ "NUM_AIRPORTTILES", "d4/de2/airport_8h.html#add0d86b6a46cf6278dae199740f4c124", null ],
    [ "NUM_AIRPORTTILES_PER_GRF", "d4/de2/airport_8h.html#a8d27f16fe10a1a90d40a8a0b5ad0e090", null ],
    [ "OUT_WAY2_block", "d4/de2/airport_8h.html#a36bf799ae037be66e8c9effc694aa03b", null ],
    [ "OUT_WAY_block", "d4/de2/airport_8h.html#ab3f52566f8f1b6b5f6b16982f81d11da", null ],
    [ "OUT_WAY_block2", "d4/de2/airport_8h.html#a8188ae2a2f4dc6c70a2aea8a56eb169a", null ],
    [ "PRE_HELIPAD_block", "d4/de2/airport_8h.html#a25a53a3e7ae80cbcc6e2b90ae22886e6", null ],
    [ "RUNWAY_IN2_block", "d4/de2/airport_8h.html#ac8a782e9d1f643f0f0c54a99dbf00987", null ],
    [ "RUNWAY_IN_block", "d4/de2/airport_8h.html#ab00a6df450cf7e7ec21e9aa128e6072f", null ],
    [ "RUNWAY_IN_OUT_block", "d4/de2/airport_8h.html#a2a166c136ebbbf56fe36cf767fbc5d68", null ],
    [ "RUNWAY_OUT2_block", "d4/de2/airport_8h.html#a91a30442650b08e2cb572029f39c73d2", null ],
    [ "RUNWAY_OUT_block", "d4/de2/airport_8h.html#a3b8c195c6cc658b31793087b2d58a50d", null ],
    [ "TAXIWAY_BUSY_block", "d4/de2/airport_8h.html#a675113d5d1ad95bb4b330597ed81d6f1", null ],
    [ "TERM1_block", "d4/de2/airport_8h.html#a8240fde23866ceebcd402110c59f11bc", null ],
    [ "TERM2_block", "d4/de2/airport_8h.html#ad4cca5b95d5ba0720ef6139c214a3ca7", null ],
    [ "TERM3_block", "d4/de2/airport_8h.html#a60b65d1f724f401cf5ee1c4f222012f6", null ],
    [ "TERM4_block", "d4/de2/airport_8h.html#a04d208abaa7b7e3ffb914311f361bb69", null ],
    [ "TERM5_block", "d4/de2/airport_8h.html#adb03bf948b385c3ffa442d3671e78de9", null ],
    [ "TERM6_block", "d4/de2/airport_8h.html#a9d1b4493066c7c335311626060fb9123", null ],
    [ "TERM7_block", "d4/de2/airport_8h.html#a134515ef1f4c05464172f4728eee1102", null ],
    [ "TERM8_block", "d4/de2/airport_8h.html#ae92a2ee696df7c115d1c2de281b4bc3e", null ],
    [ "TERM_GROUP1_block", "d4/de2/airport_8h.html#a58bda7988ccb93de888672e63e08e14b", null ],
    [ "TERM_GROUP2_block", "d4/de2/airport_8h.html#a2fbe99aab32a30788588fb1d8deb2205", null ],
    [ "TERM_GROUP2_ENTER1_block", "d4/de2/airport_8h.html#a31a846c1f8189f975d72b2f6db8fa1f0", null ],
    [ "TERM_GROUP2_ENTER2_block", "d4/de2/airport_8h.html#ad8bb747d653645960b82ca9b3fd39b8f", null ],
    [ "TERM_GROUP2_EXIT1_block", "d4/de2/airport_8h.html#a6798585ae39a010d8cd0ea70e1ad80d2", null ],
    [ "TERM_GROUP2_EXIT2_block", "d4/de2/airport_8h.html#a9a0c599cf909d0b138e72f81d4696e28", null ]
];
